==> auto-ui-2.1.25.tgz: package/es/aspect-ratio/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import './style.scss';
var AspectRatio = function (props) {
    var value = props.value, className = props.className, children = props.children, otherProps = __rest(props, ["value", "className", "children"]);
    var cls = cn('x-aspect-ratio', className);
    if (value < 0) {
        console.warn('AspectRatio组件的value值不能小于0');
        return null;
    }
    return (React.createElement("div", __assign({}, otherProps, { className: cls }),
        React.createElement("div", { className: "x-aspect-ratio__inner" }, children),
        React.createElement("div", { className: "x-aspect-ratio__ar", style: { marginTop: (1 / value) * 100 + "%" } })));
};
export default AspectRatio;

==> auto-ui-2.1.28.tgz: package/es/aspect-ratio/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import './style.scss';
var AspectRatio = function (props) {
    var value = props.value, className = props.className, children = props.children, otherProps = __rest(props, ["value", "className", "children"]);
    var cls = cn('x-aspect-ratio', className);
    if (value < 0) {
        console.warn('AspectRatio组件的value值不能小于0');
        return null;
    }
    return (React.createElement("div", __assign({}, otherProps, { className: cls }),
        React.createElement("div", { className: "x-aspect-ratio__inner" }, children),
        React.createElement("div", { className: "x-aspect-ratio__ar", style: { marginTop: (1 / value) * 100 + "%" } })));
};
export default AspectRatio;
